<?php 
/**
* A simple IP-country resolution utility which provides info on the contry Ip is assigned to.
* All data is based upon the GeoLite database from MaxMind <http://maxmind.com/>
* 
* @package GeoIP
* @author Misa Brezanac <brezanac@gmail.com>
*/
ini_set('display_errors', false);
error_reporting(E_ALL ^ E_NOTICE);

/*
* If there is an IP to locate then do it
*/
if(isset($_REQUEST['ip'])){
    /*
    * Contains all of the required functions for GeoLite database manipulation 
    */
    require "geoip.inc.php";
	
    /*
    * Can the GeoLite database be opened_ 
    */
	if(!($handle = geoip_open("GeoIP.dat", GEOIP_STANDARD))){
        $error = "GeoData baza nije dostupna!";
    } else if(trim($_REQUEST['ip']) == ""){ //IP not sent?
        $error = "Unestite IP adresu!";
    } else if(!preg_match("^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])){3}^", $_REQUEST['ip'])){ //is the IP valid
        $error = "IP adresa <strong>".htmlentities($_REQUEST['ip'], ENT_QUOTES, 'utf-8')."</strong> nije ispravna!";
    } else if(!($countryName = geoip_country_name_by_addr($handle, htmlentities($_REQUEST['ip'], ENT_QUOTES, 'utf-8'))) || !($countryCode = geoip_country_code_by_addr($handle, htmlentities($_REQUEST['ip'], ENT_QUOTES, 'utf-8')))){ //any results on that IP
        $error = "Nema rezultata za navedenu IP adresu! (<strong>{$_REQUEST['ip']}</strong>)";
    }
    
    /*
    * Closing the GeoLite database 
    */
    geoip_close($handle);
   
   /*
   * If 'nogui'' is supplied as $_GET parameter only the country code will be displayed withouth the form
   */
   if(isset($_GET['nogui'])){
        die($countryCode);      
   } else {
       $result = "IP adresa (<strong>{$_REQUEST['ip']})</strong> pripada kodu <strong>{$countryCode}</strong> čiji je vlasnik <strong>{$countryName}</strong>!"; 
   }
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>CSL GeoIP</title>
<style type="text/css">
div#mainContainer {
	position:absolute;
	left:50%;
	top:40%;
	width:300px;
	margin-left:-150px;
	text-align:center;
}
body {
	background-color: #3d6b9d;
	font-family:Verdana, Geneva, sans-serif;
	color:#FFF;
}
div#header {
	height:125px;
	background:url(images/geoip-logo.png) no-repeat center center;
}
#ip {
	text-align:center;
}
#footer {
	padding:20px 0;
	font-size:8pt;
}
#error {
	padding:5px;
	margin:10px 0;
	border:1px #D00 dashed;
	background:#CCC;
	color:#D00;
	font-size:10pt;
}
#result {
	padding:5px;
	margin:10px 0;
	border:1px #D00 dashed;
	background:#CCC;
	color:#D00;
	font-size:10pt;		
}
</style>
</head>
<body>
<div id="mainContainer">
  <div id="header"></div>
  <?php if($error) echo "<div id=\"error\">{$error}</div>"; ?>
  <div id="search">
    <form method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF'], ENT_QUOTES, 'utf-8') ?>">
      <input type="text" maxlength="15" name="ip" id="ip" />
      <input type="submit" name="searchButton" value="Pretraga" />
    </form>
  </div>
  <?php if($result && !$error) echo "<div id=\"result\">{$result}</div>";?>
  <div id="footer"> This product includes GeoLite data created by MaxMind, available from
    http://maxmind.com/. </div>
</div>
</body>
</html>